@@ -22,4 +22,7 @@
 #[cfg(all(
   feature = "micromath", 
   feature = "expose"
-))] pub use micromath;
\ No newline at end of file
+))] pub use micromath;
+
+// always publish integers (always available)
+mod integers; pub use integers::*;
\ No newline at end of file
